==> planetmint-ipld-0.0.2.tar.gz: planetmint-ipld-0.0.2/setup.py <==
import os
import re

from setuptools import setup, find_packages


def read(*names, **kwargs):
    with open(os.path.join(os.path.dirname(__file__), *names), encoding=kwargs.get("encoding", "utf8")) as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r'^__version__ = [\'"]([^\'"]*)[\'"]', version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


with open("README.rst", encoding="utf-8") as readme:
    long_description = readme.read()


tests_require = [
    "pep8",
    "pyflakes",
    "pylint",
    "pytest",
    "pytest-cov",
    "pytest-xdist",
    "pytest-flask",
]

dev_require = [
    "ipdb",
    "ipython",
]

setup(
    name="planetmint-ipld",
    packages=find_packages(exclude=["tests*"]),
    version=find_version("ipld", "__init__.py"),
    author="Tim Daubenschuetz",
    author_email="tim.daubenschuetz@gmail.com",
    description="An IPLD implementation in Python",
    long_description=long_description,
    license="MIT License",
    keywords="ipld python ipfs bigchaindb",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Topic :: Software Development",
    ],
    install_requires=[
        "cbor==1.0.0",
        "base58>=2.1.1",
        "planetmint-pymultihash",
        "planetmint-multiaddr",
    ],
    setup_requires=["pytest-runner"],
    tests_require=tests_require,
    extras_require={
        "test": tests_require,
        "dev": dev_require + tests_require,
    },
)

==> planetmint-ipld-0.0.3.tar.gz: planetmint-ipld-0.0.3/setup.py <==
import os
import re

from setuptools import setup, find_packages


def read(*names, **kwargs):
    with open(os.path.join(os.path.dirname(__file__), *names), encoding=kwargs.get("encoding", "utf8")) as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r'^__version__ = [\'"]([^\'"]*)[\'"]', version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


with open("README.rst", encoding="utf-8") as readme:
    long_description = readme.read()


tests_require = [
    "pep8",
    "pyflakes",
    "pylint",
    "pytest",
    "pytest-cov",
    "pytest-xdist",
    "pytest-flask",
]

dev_require = [
    "ipdb",
    "ipython",
]

setup(
    name="planetmint-ipld",
    packages=find_packages(exclude=["tests*"]),
    version=find_version("ipld", "__init__.py"),
    author="Tim Daubenschuetz",
    author_email="tim.daubenschuetz@gmail.com",
    description="An IPLD implementation in Python",
    long_description=long_description,
    license="MIT License",
    keywords="ipld python ipfs bigchaindb",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Topic :: Software Development",
    ],
    install_requires=[
        "cbor==1.0.0",
        "base58>=2.1.1",
        "planetmint-pymultihash>=0.9.2",
        "planetmint-multiaddr",
    ],
    setup_requires=["pytest-runner"],
    tests_require=tests_require,
    extras_require={
        "test": tests_require,
        "dev": dev_require + tests_require,
    },
)
